@@ -58,7 +58,9 @@ def _convert_req(req_dict):
             Marker(_convert_python(req_dict.pop("python")).as_marker_string())
         )
     if markers:
-        req_dict["marker"] = str(functools.reduce(operator.and_, markers))
+        req_dict["marker"] = str(functools.reduce(operator.and_, markers)).replace(
+            '"', "'"
+        )
     if "rev" in req_dict or "branch" in req_dict or "tag" in req_dict:
         req_dict["ref"] = req_dict.pop(
             "rev", req_dict.pop("tag", req_dict.pop("branch", None))
